//+------------------------------------------------------------------+
//|                                                         test01.mq5 |
//|                                                           105060 |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "105060"
#property link      "https://www.mql5.com"
#property version   "1.00"
//+------------------------------------------------------------------+
//| Include                                                          |
//+------------------------------------------------------------------+
#include <Expert\Expert.mqh>
//--- available signals
#include <Expert\Signal\SignalCCI.mqh>
#include <Expert\Signal\SignalDEMA.mqh>
#include <Expert\Signal\SignalMACD.mqh>
//--- available trailing
#include <Expert\Trailing\TrailingNone.mqh>
//--- available money management
#include <Expert\Money\MoneyFixedLot.mqh>
//+------------------------------------------------------------------+
//| Inputs                                                           |
//+------------------------------------------------------------------+
//--- inputs for expert
input string             Expert_Title            ="test01";      // Document name
ulong                    Expert_MagicNumber      =21739;       //
bool                     Expert_EveryTick        =false;       //
//--- inputs for main signal
input int                Signal_ThresholdOpen    =10;          // Signal threshold value to open [0...100]
input int                Signal_ThresholdClose   =10;          // Signal threshold value to close [0...100]
input double             Signal_PriceLevel       =0.0;         // Price level to execute a deal
input double             Signal_StopLevel        =20.0;        // Stop Loss level (in points)
input double             Signal_TakeLevel        =30.0;        // Take Profit level (in points)
input int                Signal_Expiration       =4;           // Expiration of pending orders (in bars)
input int                Signal_CCI_PeriodCCI    =15;          // Commodity Channel Index(15,...) CCI Period of calculation
input ENUM_APPLIED_PRICE Signal_CCI_Applied      =PRICE_CLOSE; // Commodity Channel Index(15,...) CCI Prices series
input double             Signal_CCI_Weight       =1.0;         // Commodity Channel Index(15,...) CCI Weight [0...1.0]
input int                Signal_DEMA_PeriodMA    =20;          // Double Exponential Moving Average EMA Period of averaging
input int                Signal_DEMA_Shift       =0;           // Double Exponential Moving Average EMA Time shift
input ENUM_APPLIED_PRICE Signal_DEMA_Applied     =PRICE_CLOSE; // Double Exponential Moving Average EMA Prices series
input double             Signal_DEMA_Weight      =1.0;         // Double Exponential Moving Average EMA Weight [0...1.0]
input int                Signal_MACD_PeriodFast  =12;          // MACD(12,26,9,PRICE_CLOSE) MACD Period of fast EMA
input int                Signal_MACD_PeriodSlow  =26;          // MACD(12,26,9,PRICE_CLOSE) MACD Period of slow EMA
input int                Signal_MACD_PeriodSignal=9;           // MACD(12,26,9,PRICE_CLOSE) MACD Period of averaging of difference
input ENUM_APPLIED_PRICE Signal_MACD_Applied     =PRICE_CLOSE; // MACD(12,26,9,PRICE_CLOSE) MACD Prices series
input double             Signal_MACD_Weight      =1.0;         // MACD(12,26,9,PRICE_CLOSE) MACD Weight [0...1.0]
//--- inputs for money
input double             Money_FixLot_Percent    =10.0;        // Percent
input double             Money_FixLot_Lots       =0.1;         // Fixed volume
//+------------------------------------------------------------------+
//| Global expert object                                             |
//+------------------------------------------------------------------+
CExpert ExtExpert;
//+------------------------------------------------------------------+
//| Initialization function of the expert                            |
//+------------------------------------------------------------------+
int OnInit()
  {
//--- Initializing expert
   if(!ExtExpert.Init(Symbol(),Period(),Expert_EveryTick,Expert_MagicNumber))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing expert");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Creating signal
   CExpertSignal *signal=new CExpertSignal;
   if(signal==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating signal");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//---
   ExtExpert.InitSignal(signal);
   signal.ThresholdOpen(Signal_ThresholdOpen);
   signal.ThresholdClose(Signal_ThresholdClose);
   signal.PriceLevel(Signal_PriceLevel);
   signal.StopLevel(Signal_StopLevel);
   signal.TakeLevel(Signal_TakeLevel);
   signal.Expiration(Signal_Expiration);
//--- Creating filter CSignalCCI
   CSignalCCI *filter0=new CSignalCCI;
   if(filter0==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter0");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
   signal.AddFilter(filter0);
//--- Set filter parameters
   filter0.Symbol("CCI");
   filter0.PeriodCCI(Signal_CCI_PeriodCCI);
   filter0.Applied(Signal_CCI_Applied);
   filter0.Weight(Signal_CCI_Weight);
//--- Creating filter CSignalDEMA
   CSignalDEMA *filter1=new CSignalDEMA;
   if(filter1==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter1");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
   signal.AddFilter(filter1);
//--- Set filter parameters
   filter1.Symbol("EMA");
   filter1.PeriodMA(Signal_DEMA_PeriodMA);
   filter1.Shift(Signal_DEMA_Shift);
   filter1.Applied(Signal_DEMA_Applied);
   filter1.Weight(Signal_DEMA_Weight);
//--- Creating filter CSignalMACD
   CSignalMACD *filter2=new CSignalMACD;
   if(filter2==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating filter2");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
   signal.AddFilter(filter2);
//--- Set filter parameters
   filter2.Symbol("MACD");
   filter2.PeriodFast(Signal_MACD_PeriodFast);
   filter2.PeriodSlow(Signal_MACD_PeriodSlow);
   filter2.PeriodSignal(Signal_MACD_PeriodSignal);
   filter2.Applied(Signal_MACD_Applied);
   filter2.Weight(Signal_MACD_Weight);
//--- Creation of trailing object
   CTrailingNone *trailing=new CTrailingNone;
   if(trailing==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating trailing");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Add trailing to expert (will be deleted automatically))
   if(!ExtExpert.InitTrailing(trailing))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing trailing");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Set trailing parameters
//--- Creation of money object
   CMoneyFixedLot *money=new CMoneyFixedLot;
   if(money==NULL)
     {
      //--- failed
      printf(__FUNCTION__+": error creating money");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Add money to expert (will be deleted automatically))
   if(!ExtExpert.InitMoney(money))
     {
      //--- failed
      printf(__FUNCTION__+": error initializing money");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Set money parameters
   money.Percent(Money_FixLot_Percent);
   money.Lots(Money_FixLot_Lots);
//--- Check all trading objects parameters
   if(!ExtExpert.ValidationSettings())
     {
      //--- failed
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- Tuning of all necessary indicators
   if(!ExtExpert.InitIndicators())
     {
      //--- failed
      printf(__FUNCTION__+": error initializing indicators");
      ExtExpert.Deinit();
      return(INIT_FAILED);
     }
//--- ok
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Deinitialization function of the expert                          |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   ExtExpert.Deinit();
  }
//+------------------------------------------------------------------+
//| "Tick" event handler function                                    |
//+------------------------------------------------------------------+
void OnTick()
  {
   #include<Trade\Trade.mqh>
   CTrade trade;
   
   // Get le Ask Price
   double Ask= NormalizeDouble(SymbolInfoDouble(_Symbol, SYMBOL_ASK),_Digits);
   //array for the prices
   MqlRates PriceInfo[];
   
   //sort the price array from current candle downwards
   ArraySetAsSeries(PriceInfo,true);
   
   
   //We fill the array with the price data
   int PriceData=CopyRates(_Symbol,_Period,0,4,PriceInfo);
   
   //conditions to buy 
   if("CCI" > 105)
   
   
            //If the CCI value is above 100 we going to buy
   if("MACD" > Signal_MACD_PeriodSignal) //If the MACD is above the signal line we are going 
   if("EMA" > Signal_DEMA_Weight)                //If the candles are above the EMA
   
  
   //if we have no open positions
   if (PositionsTotal()==0)
   {
   //buy
   trade.Buy( 
              
               0.1, //Lots
               NULL, //current symbol
               Ask,  //buy price
               Ask-30*_Point, //Stop Loss
               Ask+20*_Point, // Take Profit
               NULL //comments
            
              
              );
              
   }
 
   
   ExtExpert.OnTick();
   
  }
//+------------------------------------------------------------------+
//| "Trade" event handler function                                   |
//+------------------------------------------------------------------+
void OnTrade()
  {
   ExtExpert.OnTrade();
  }
//+------------------------------------------------------------------+
//| "Timer" event handler function                                   |
//+------------------------------------------------------------------+
void OnTimer()
  {
   ExtExpert.OnTimer();
  }
//+------------------------------------------------------------------+
